@@ -61,9 +61,20 @@ class ObservableListView(PyHtmlView):
         obj.element_index_used = False
         return obj
 
+    def _recreate(self):
+        self._wrapped_data_lock.acquire()
+        self._wrapped_data = []
+        for item in self.subject:
+            self._wrapped_data.append(self._create_item(item))
+        self._wrapped_data_lock.release()
+
     def _on_subject_updated(self, source, **kwargs):
         try:
             self._wrapped_data_lock.acquire()
+            if "action" not in kwargs:
+                self._recreate()
+                self.update()
+                return
 
             if kwargs["action"] in ["append", "insert"]:
                 obj = self._create_item(kwargs["item"])
@@ -102,9 +113,15 @@ class ObservableListView(PyHtmlView):
                 [item.update() for item in self._wrapped_data[kwargs["index"]:] if item.element_index_used is True]
 
             if kwargs["action"] == "sort":
+                self._recreate()
                 self.update()
             if kwargs["action"] == "reverse":
+                self._recreate()
                 self.update()
+            if kwargs["action"] == "clear":
+                self._wrapped_data.clear()
+                self.update()
+
         finally:
             self._wrapped_data_lock.release()
 
