@@ -124,18 +124,12 @@ class PyHtmlView:
         """
         if self.is_visible is True and remove_from_dom is True:
             self.call_javascript("pyhtmlgui.remove_element", [self.uid], skip_results=True)
-        if self.is_visible is True:
-            self.set_visible(False)
+        self.set_visible(False)
         try:
             self.parent._remove_child(self)
         except:
             pass
-
-        for child in [c for c in self._children]:
-            try:
-                child.delete(remove_from_dom=False)
-            except:
-                pass
+        self._children.clear()
 
     def set_visible(self, visible: bool) -> None:
         """
@@ -152,7 +146,7 @@ class PyHtmlView:
                     observable().detach_observer(target())  # resolve weak references
                 except Exception:
                     pass
-            for child in [c for c in self._children if c.is_visible is True]:
+            for child in self._children:
                 try:
                     child.set_visible(False)
                 except:
@@ -198,7 +192,7 @@ class PyHtmlView:
         if self._subject is None:  # Observed object died before render
             return None
 
-        for child in [c for c in self._children]:
+        for child in self._children:
             try:
                 child.__was_rendered = False
             except:
@@ -218,10 +212,10 @@ class PyHtmlView:
             print(msg)
 
         # set children that have not been rendered in last pass to invisible
-        children = [c for c in self._children if c.__was_rendered is False and c.is_visible is True]
-        for child in children:
+        for child in self._children:
             try:
-                child.set_visible(False)
+                if child.__was_rendered is False and child.is_visible is True:
+                    child.set_visible(False)
             except:
                 pass
 
